import { describe, it, expect } from 'vitest'
import { build, createServer } from 'vite'
import rollupPluginPo2Json from '@open-xchange/rollup-plugin-po2json'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle, getPort } from '../util'

const __dirname = import.meta.dirname

describe('Multiple dictionaries gettext scenario', () => {
  it('works', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {
            i18n: 'i18n'
          },
          cache: true,
          onwarn (warning, warn) {
            if (warning.code === 'FILE_NAME_CONFLICT' && /".*\.[a-z]{2}_[A-Z]{2}\.js"/.test(warning.message)) return
            warn(warning)
          }
        }
      },
      plugins: [rollupPluginPo2Json({
        poFiles: __dirname + '/i18n/*.po'
      }), vitePluginOxManifests({

      })]
    })

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(9)
    expect(manifests['register.js'].meta.manifests[0].namespace).toBe('test')
    expect(manifests['../../foobar.js'].meta.manifests[0].namespace).toBe('i18n')
    expect(manifests['../../i18n'].meta.manifests[0].namespace).toBe('i18n')
  })

  it('works in dev mode', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [rollupPluginPo2Json({
        poFiles: __dirname + '/i18n/*.po'
      }), vitePluginOxManifests({

      })]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/api/manifest.json`)
    const manifests = await res.json()
    await server.close()

    expect(manifests).toHaveLength(3)
    expect(manifests[0].namespace).toBe('i18n')
    expect(manifests[0].path).toBe('foobar')
    expect(manifests[1].namespace).toBe('i18n')
    expect(manifests[1].path).toBe('i18n')
    expect(manifests[2].namespace).toBe('test')
    expect(manifests[2].path).toContain('register')
  })
})
