import { describe, it, expect } from 'vitest'
import { build, createServer } from 'vite'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle, getPort } from '../util'

const __dirname = import.meta.dirname

describe('Settings like in core', () => {
  it('works', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        write: false,
        rollupOptions: {
          input: {},
          external: ['@/io.ox/core/settings']
        }
      },
      plugins: [
        vitePluginOxManifests({})
      ]
    })
    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(2)
    expect(manifests['settings.js'].meta.manifests[0].namespace).toBe('settings')
  })

  it('works in dev mode', async () => {
    const server = await createServer({
      root: __dirname,
      logLevel: 'silent',
      plugins: [
        vitePluginOxManifests({})
      ]
    })
    const PORT = await getPort()
    await server.listen(PORT)

    const res = await fetch(`http://localhost:${PORT}/api/manifest.json`)
    const manifests = await res.json()
    await server.close()

    expect(manifests).toHaveLength(2)
    expect(manifests[0].namespace).toBe('settings')
  })
})
